import { Module } from '../../module/index';
import { Store } from '../store/index';
import { EntityStoreConfig } from './configs/index';
import { Entity } from './entity';
import { EntityList } from './entity-list';
import { EntitySchema } from './entity-schema/index';
import { EntityPath } from './entity-path/index';
import { EntityChangeHistory } from './entity-change/index';
import { EntityStateQuery } from './entity-state-query';
import { EntityStateUpdater } from './entity-state-updater';
import { EntityPagination, Pagination } from './types';
/**
 * EntityState定义
 */
declare class EntityState<E extends Entity> {
    entities: E[];
    currentEntity: E | null;
}
/**
 * 实体状态
 */
declare class EntityStore<S extends EntityState<Entity>> extends Store<S> {
    /**
     * 分页信息
     */
    private entityPagination;
    /**
     * 实体描述
     */
    protected entitySchema: EntitySchema;
    /**
     * 根实体列表
     */
    protected entityList: EntityList<Entity>;
    /**
   * 实体状态查询器
   */
    entityQuery: EntityStateQuery;
    /**
     * 实体更新器
     */
    entityUpdater: EntityStateUpdater;
    /**
     * 变更历史记录
     */
    entityChangeHistory: EntityChangeHistory;
    /**
     * 构造函数
     */
    constructor(module: Module);
    /**
     * 初始化
     */
    init(config: EntityStoreConfig): void;
    /**
     * 获取实体列表
     */
    getEntityList(): EntityList<Entity>;
    /**
     * 根据path获取实体列表
     */
    getEntityListByPath(path: string | EntityPath): EntityList<Entity>;
    /**
     * 获取根实体集合
     */
    getEntities(): Entity[];
    /**
     * 根据Path获取根实体集合
     */
    getEntitiesByPath(path: string | EntityPath): Entity[];
    /**
     * 根据ID获取根实体
     */
    getEntityById(id: string): Entity | undefined;
    /**
     * 根据Path获取实体
     */
    getEntityByPath(path: string | EntityPath): Entity | undefined;
    /**
     * 根据Path获取字段值
     * @param path 字段路径
     * @returns
     */
    getValueByPath(path: string | EntityPath): any;
    /**
     * 根据ID获取根实体
     */
    getCurrentEntity(): Entity;
    /**
     * 根据Path获取实体
     */
    getCurrentEntityByPath(path: string | EntityPath): Entity;
    /**
     * 加载根实体集合
     */
    loadEntities(entities: Entity[]): void;
    /**
     * 根据Path加载实体集合
     */
    loadEntitesByPath(path: string | EntityPath, entities: Entity[]): void;
    /**
     * 加载根实体集合
     */
    appendEntities(entities: Entity[]): void;
    /**
     * 根据Path加载实体集合
     */
    appendEntitesByPath(path: string | EntityPath, entities: Entity[]): void;
    /**
     * 根据ID删除根实体
     */
    removeEntityById(id: string, emitCurrentChangeEvent?: boolean): void;
    /**
     * 根据父Paht和ID删除实体
     */
    removeEntityByPath(path: string | EntityPath, id: string): void;
    /**
     * 根据ID批量删除根实体
     */
    removeEntitiesByIds(ids: string[]): void;
    /**
     * 根据path和ID批量删除实体
     */
    removeEntitiesByPath(path: string | EntityPath, ids: string[]): void;
    /**
     * 根据ID更新实体
     */
    updateEntityById(id: string, values: any): void;
    /**
     * 根据Path更新实体
     */
    updateEntityByPath(path: string, values: any): void;
    /**
     * 根据path更新字段值
     */
    setValueByPath(path: string | EntityPath, value: any): void;
    /**
     * 设置当前根实体
     */
    changeCurrentEntityById(id: string): void;
    /**
     * 根据Path设置当前实体
     */
    changeCurrentEntityByPath(path: string | EntityPath, id: string): void;
    /**
     * 构造实体路径
     */
    createPath(path: string | string[] | EntityPath, isEntityListPath?: boolean): EntityPath;
    /**
     * 获取实体结构描述
     */
    getEntitySchema(): EntitySchema;
    /**
     * 更新实体分页配置
     */
    setEntityPagination(entityPagination: EntityPagination): void;
    /**
     * 获取实体分页配置
     */
    getEntityPagination(): EntityPagination;
    /**
     * 更新指定实体分页信息
     */
    setPaginationByPath(path: string | string[] | EntityPath, pagination: Partial<Pagination>): void;
    /**
     * 获取分页信息
     */
    getPaginationByPath(path: string | string[] | EntityPath): Pagination;
    /**
     * 刷新State
     */
    refreshState(): void;
    /**
     * 触发变更
     */
    triggerChange(change: any): void;
    /**
     * 转换为JSON
     */
    toJSON(): {
        entityList: any[];
        currentEntity: any;
    };
}
export { EntityState, EntityStore };
