/**
 * 验证规则
 */
interface ValidationRule {
    name: string;
    message?: string;
    [key: string]: any;
}
/**
 * 必填验证
 */
interface RequiredValidationRule extends ValidationRule {
    name: 'required';
}
/**
 * 静态验证
 */
interface StaticValidationRule extends ValidationRule {
    name: 'static';
    valid: boolean;
}
/**
 * 字符串最大长度
 */
interface MaxLengthValidationRule extends ValidationRule {
    name: 'maxLength';
    maxLength: number;
}
/**
 * 字符串最小长度
 */
interface MinLengthValidationRule extends ValidationRule {
    name: 'minLength';
    minLength: number;
}
/**
 * 最大值
 */
interface MaxValueValidationRule extends ValidationRule {
    name: 'maxValue';
    maxValue: number;
}
/**
 * 最小值
 */
interface MinValueValidationRule extends ValidationRule {
    name: 'minValue';
    minValue: number;
}
/**
 * 最大值
 */
interface MaxDateValidationRule extends ValidationRule {
    name: 'maxDate';
    maxDate: Date | string;
}
/**
 * 最小值
 */
interface MinDateValidationRule extends ValidationRule {
    name: 'minDate';
    minDate: Date | string;
}
/**
 * 正则验证
 */
interface FormatValidationRule extends ValidationRule {
    name: 'format';
    format: 'mobilePhone' | 'landlinePhone' | 'mobileOrLandlinePhone' | 'postcode' | 'email' | 'idCardNumber' | 'carNumber' | 'subjectCode';
}
/**
 * 正则验证
 */
interface PatternValidationRule extends ValidationRule {
    name: 'pattern';
    pattern: string | RegExp;
}
/**
 * 自定义验证函数
 */
type CustomValidatorFunction = (value: any) => boolean;
/**
 * 自定义函数验证器
 */
interface CustomFunctionValidationRule extends ValidationRule {
    name: 'custom-function';
    customFn: CustomValidatorFunction;
}
/**
 * 错误信息
 */
interface ValidationError {
    name: string;
    message: string;
    [key: string]: any;
}
/**
 * 错误信息集合
 */
interface ValidationErrors {
    [key: string]: ValidationError;
}
/**
 * 验证器
 */
interface Validator {
    name: string;
    validate(value: any, rule: ValidationRule): ValidationError | null;
}
export { ValidationRule, RequiredValidationRule, StaticValidationRule, MaxLengthValidationRule, MinLengthValidationRule, MaxValueValidationRule, MinValueValidationRule, MaxDateValidationRule, MinDateValidationRule, FormatValidationRule, PatternValidationRule, CustomValidatorFunction, CustomFunctionValidationRule, Validator, ValidationError, ValidationErrors };
